##  Sending Notifications on Quality State Changes
Whenever the Quality State field changes to Approved, notifications are sent to multiple stakeholders so that they could start the multi-stakeholder review process.
Set up an automation where the triggering event is Quality State changes to and the value is Approved. The action is to send a webhook to a target URL. On your automation platform, configure a process to receive this webhook and send a notification to multiple users, such as through the messenger that your organization uses.
